@@ -8,6 +8,7 @@ Usage::
     from mypy_boto3_mediatailor import (
         Client,
         GetChannelSchedulePaginator,
+        ListAlertsPaginator,
         ListChannelsPaginator,
         ListPlaybackConfigurationsPaginator,
         ListSourceLocationsPaginator,
@@ -21,6 +22,7 @@ Usage::
     session_client: MediaTailorClient = session.client("mediatailor")
 
     get_channel_schedule_paginator: GetChannelSchedulePaginator = client.get_paginator("get_channel_schedule")
+    list_alerts_paginator: ListAlertsPaginator = client.get_paginator("list_alerts")
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
     list_source_locations_paginator: ListSourceLocationsPaginator = client.get_paginator("list_source_locations")
@@ -30,6 +32,7 @@ Usage::
 from .client import MediaTailorClient
 from .paginator import (
     GetChannelSchedulePaginator,
+    ListAlertsPaginator,
     ListChannelsPaginator,
     ListPlaybackConfigurationsPaginator,
     ListSourceLocationsPaginator,
@@ -42,6 +45,7 @@ Client = MediaTailorClient
 __all__ = (
     "Client",
     "GetChannelSchedulePaginator",
+    "ListAlertsPaginator",
     "ListChannelsPaginator",
     "ListPlaybackConfigurationsPaginator",
     "ListSourceLocationsPaginator",
